[llvm-commits] [llvm] r45868 - /llvm/trunk/lib/Target/X86/X86ISelLowering.cpp

Arnold Schwaighofer arnold.schwaighofer at gmail.com
Fri Jan 11 09:10:15 PST 2008


Author: arnolds
Date: Fri Jan 11 11:10:15 2008
New Revision: 45868

URL: http://llvm.org/viewvc/llvm-project?rev=45868&view=rev
Log:
hrm - correct spelling.
Actually were not riding any arguments. Sadly there is no semantic spell checker that is going to safe you from such a mistake.


Modified:
    llvm/trunk/lib/Target/X86/X86ISelLowering.cpp

Modified: llvm/trunk/lib/Target/X86/X86ISelLowering.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/X86/X86ISelLowering.cpp?rev=45868&r1=45867&r2=45868&view=diff

==============================================================================
--- llvm/trunk/lib/Target/X86/X86ISelLowering.cpp (original)
+++ llvm/trunk/lib/Target/X86/X86ISelLowering.cpp Fri Jan 11 11:10:15 2008
@@ -1008,16 +1008,16 @@
 }
 
 
 // IsPossiblyOverriddenArgumentOfTailCall - Check if the operand could possibly
 // be overridden when lowering the outgoing arguments in a tail call. Currently
 // the implementation of this call is very conservative and assumes all
 // arguments sourcing from FORMAL_ARGUMENTS or a CopyFromReg with virtual
 // registers would be overridden by direct lowering. 
 // Possible improvement:
 // Check FORMAL_ARGUMENTS corresponding MERGE_VALUES for CopyFromReg nodes
 // indicating inreg passed arguments which also need not be lowered to a safe
 // stack slot.
-static bool IsPossiblyOverriddenArgumentOfTailCall(SDOperand Op) {
+static bool IsPossiblyOverwrittenArgumentOfTailCall(SDOperand Op) {
   RegisterSDNode * OpReg = NULL;
   if (Op.getOpcode() == ISD::FORMAL_ARGUMENTS ||
       (Op.getOpcode()== ISD::CopyFromReg &&
@@ -1359,7 +1359,7 @@
     if (VA.isRegLoc()) {
       RegsToPass.push_back(std::make_pair(VA.getLocReg(), Arg));
     } else {
-      if (!IsTailCall || IsPossiblyOverriddenArgumentOfTailCall(Arg)) {
+      if (!IsTailCall || IsPossiblyOverwrittenArgumentOfTailCall(Arg)) {
         assert(VA.isMemLoc());
         if (StackPtr.Val == 0)
           StackPtr = DAG.getCopyFromReg(Chain, X86StackPtr, getPointerTy());
@@ -1438,7 +1438,7 @@
         FI = MF.getFrameInfo()->CreateFixedObject(OpSize, Offset);
         FIN = DAG.getFrameIndex(FI, MVT::i32);
         SDOperand Source = Arg;
-        if (IsPossiblyOverriddenArgumentOfTailCall(Arg)){
+        if (IsPossiblyOverwrittenArgumentOfTailCall(Arg)){
           // Copy from stack slots to stack slot of a tail called function. This
           // needs to be done because if we would lower the arguments directly
           // to their real stack slot we might end up overwriting each other.
@@ -1008,16 +1008,16 @@
 
 
-// IsPossiblyOverriddenArgumentOfTailCall - Check if the operand could possibly
-// be overridden when lowering the outgoing arguments in a tail call. Currently
+// IsPossiblyOverwrittenArgumentOfTailCall - Check if the operand could possibly
+// be overwritten when lowering the outgoing arguments in a tail call. Currently
 // the implementation of this call is very conservative and assumes all
 // arguments sourcing from FORMAL_ARGUMENTS or a CopyFromReg with virtual
@@ -1008,16 +1008,16 @@
 // the implementation of this call is very conservative and assumes all
 // arguments sourcing from FORMAL_ARGUMENTS or a CopyFromReg with virtual
-// registers would be overridden by direct lowering. 
+// registers would be overwritten by direct lowering.  
 // Possible improvement:
 // Check FORMAL_ARGUMENTS corresponding MERGE_VALUES for CopyFromReg nodes





More information about the llvm-commits mailing list